@@ -80,9 +80,6 @@ def main(argv=None):
     """
     if argv is None:
         argv = sys.argv[1:]
-        encoding = locale.getdefaultlocale()[1]
-        if encoding:
-            argv = [a.decode(encoding) for a in sys.argv[1:]]
 
     # find command position
     pos, skip_next = 0, False
